@@ -2,10 +2,12 @@ from lxml import etree
 import requests
 from django.conf import settings
 from django import template
+from wagtail.embeds.embeds import get_embed
+from wagtail.embeds.exceptions import EmbedException
 
-from .. import constants
-from ..amp.utils import amp_mode_active
-from ..amp.mixins import AmpMixin
+from webspace.cms import constants
+from webspace.cms.amp.utils import amp_mode_active
+from webspace.cms.amp.mixins import AmpMixin
 
 register = template.Library()
 
@@ -26,19 +28,8 @@ AMP_SCRIPTS = {
 
 class AMPImage(template.Node):
 
-    def __init__(self, nodelist, layout='responsive', size=None):
+    def __init__(self, nodelist):
         self.nodelist = nodelist
-        self.layout = layout.replace('\'', '') if layout else layout
-        self.size = size.replace('\'', '') if size else size
-        self.classname = ''
-
-    @property
-    def width(self):
-        return self.size.split('x')[0] if self.size else None
-
-    @property
-    def height(self):
-        return self.size.split('x')[1] if self.size else None
 
     def get_match(self, classname):
         for key, value in SIZES_IMG.items():
@@ -51,18 +42,24 @@ class AMPImage(template.Node):
             html = self.nodelist.render(context)
             tree = etree.XML(html)
             classname = tree.get('class')
-            match = self.get_match(classname)
+            layout = tree.get('data-layout', 'responsive')
+            width = tree.get('data-width', '500')
+            height = tree.get('data-height', '500')
+
+            match = None
+            if classname:
+                match = self.get_match(classname)
 
             # Check icons or custom
             if match:
-                tree.set('layout', self.layout)
+                tree.set('layout', layout)
                 tree.set('width', str(SIZES_IMG[match]))
                 tree.set('height', str(SIZES_IMG[match]))
             else:
-                tree.set('layout', self.layout)
-                if self.size:
-                    tree.set('width', self.width)
-                    tree.set('height', self.height)
+                tree.set('layout', layout)
+                if width and height:
+                    tree.set('width', width)
+                    tree.set('height', height)
 
             # Check lazy
             lazy_src = tree.get('data-src')
@@ -82,24 +79,37 @@ class AMPImage(template.Node):
 def amp_img(parser, token):
     nodelist = parser.parse(('endamp_img',))
     parser.delete_first_token()
-    tokens = token.split_contents()
-    return AMPImage(
-        nodelist=nodelist,
-        layout=tokens[1] if len(tokens) > 1 else 'responsive',
-        size=tokens[2] if len(tokens) > 2 else None,
-    )
+    return AMPImage(nodelist=nodelist)
 
 
-@register.inclusion_tag('%s/templatetags/content-safe.html' % constants.BLOCK_TEMPLATES_PATH, takes_context=True)
-def amp_custom(context):
-    request = context['request']
-    http = 'https://' if request.is_secure == 'local' else 'http://'
-    path_url = "/static/dist/css/cmsamp%s.css" % settings.VERSION
-    url = http + request.get_host() + path_url
-    response = requests.get(url)
-    return {
-        'content': response.content.decode().replace('\n', '').replace('!important', '')
-    }
+class AMPStyles(template.Node):
+
+    def __init__(self, nodelist):
+        self.nodelist = nodelist
+
+    def render(self, context):
+        if amp_mode_active():
+            html = self.nodelist.render(context)
+            tree = etree.XML(html)
+            href = tree.get('href')
+            request = context['request']
+            http = 'https://' if request.is_secure() else 'http://'
+            host = request.get_host()
+            if host == 'localhost':
+                host += ':8080'
+            url = http + host + href
+            response = requests.get(url)
+            css = response.content.decode().replace('\n', '').replace('!important', '')
+            ret = "<style amp-custom>%s</style>" % css
+            return ret
+        return self.nodelist.render(context)
+
+
+@register.tag('amp_styles')
+def amp_styles(parser, token):
+    nodelist = parser.parse(('endamp_styles',))
+    parser.delete_first_token()
+    return AMPStyles(nodelist=nodelist)
 
 
 @register.inclusion_tag('%s/templatetags/content-safe.html' % constants.BLOCK_TEMPLATES_PATH, takes_context=True)
@@ -110,9 +120,13 @@ def amp_scripts(context):
         if hasattr(block.block, 'amp_scripts'):
             for script in block.block.amp_scripts:
                 if script not in scripts:
-                    if script == 'carousel':
+                    if block.block_type == 'cards' and script == 'carousel':
                         if block.value['carousel']:
                             scripts.append(script)
+                    if block.block_type == 'media_text' and script == 'iframe':
+                        for media in block.value['media']:
+                            if media.block_type == 'embed':
+                                scripts.append(script)
                     else:
                         scripts.append(script)
     html = ''
@@ -137,8 +151,6 @@ def amp_canonical(context):
 
 @register.filter
 def amp_embed(url):
-    from wagtail.embeds.embeds import get_embed
-    from wagtail.embeds.exceptions import EmbedException
     try:
         embed = get_embed(url)
         tree = etree.XML(embed.html.replace('allowfullscreen', ''))
